@@ -10,10 +10,11 @@ from .dotpay.tests import TestDotpayProvider
 from .paypal.tests import TestPaypalProvider
 from .stripe.tests import TestStripeProvider
 from .wallet.tests import TestGoogleWalletProvider
+from .dummy.tests import TestDummy3DSProvider
 
 
 __all__ = ['TestDotpayProvider', 'TestGoogleWalletProvider',
-           'TestPaypalProvider', 'TestStripeProvider']
+           'TestPaypalProvider', 'TestStripeProvider', 'TestDummy3DSProvider']
 
 
 class TestProviderFactory(TestCase):
